==> apimgmt-app-1.1.0-20251024.055834-1-sources.jar: com/digiwin/athena/apimgmt/model/ProjectVersionRelation.java <==
package com.digiwin.athena.apimgmt.model;

import com.baomidou.mybatisplus.annotation.TableName;
import com.baomidou.mybatisplus.annotation.TableId;
import com.baomidou.mybatisplus.annotation.IdType;
import com.baomidou.mybatisplus.annotation.TableField;

import lombok.Getter;
import lombok.Setter;

import java.io.Serializable;
import java.util.Date;

@TableName("project_version_relation")
public class ProjectVersionRelation implements Serializable{
    /** 主键 */
    @TableId(type = IdType.AUTO)
    private Long relationId ;

    @Getter
    @Setter
    @TableField(value = "api_id")
    private Long apiId;

    /** API的ID */
    @TableField(exist = false)
    private StandardApi standardApi;

    @TableField("project_id")
    private Long projectId;

    @TableField("project_version_id")
    private Long projectVersionId;
    @TableField("CREATED_BY")
    private String createdBy;

    @TableField("CREATED_TIME")
    private Date createdTime;

    public String getCreatedBy() {
        return createdBy;
    }

    public void setCreatedBy(String createdBy) {
        this.createdBy = createdBy;
    }

    public Date getCreatedTime() {
        return createdTime;
    }

    public void setCreatedTime(Date createdTime) {
        this.createdTime = createdTime;
    }

    public Long getRelationId() {
        return relationId;
    }

    public void setRelationId(Long relationId) {
        this.relationId = relationId;
    }

    public StandardApi getStandardApi() {
        return standardApi;
    }

    public void setStandardApi(StandardApi standardApi) {
        this.standardApi = standardApi;
    }

    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }

    public Long getProjectVersionId() {
        return projectVersionId;
    }

    public void setProjectVersionId(Long projectVersionId) {
        this.projectVersionId = projectVersionId;
    }

}

==> apimgmt-app-1.1.0-20251024.114014-2-sources.jar: com/digiwin/athena/apimgmt/model/ProjectVersionRelation.java <==
package com.digiwin.athena.apimgmt.model;

import com.baomidou.mybatisplus.annotation.IdType;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableId;
import com.baomidou.mybatisplus.annotation.TableName;
import lombok.Getter;
import lombok.Setter;

import java.io.Serializable;
import java.util.Date;

@TableName(value = "project_version_relation", resultMap = "BaseResultMap")
public class ProjectVersionRelation implements Serializable{
    /** 主键 */
    @TableId(type = IdType.AUTO)
    private Long relationId ;

    @Getter
    @Setter
    @TableField(value = "api_id")
    private Long apiId;

    /** API的ID */
    @TableField(exist = false)
    private StandardApi standardApi;

    @TableField("project_id")
    private Long projectId;

    @TableField("project_version_id")
    private Long projectVersionId;
    @TableField("CREATED_BY")
    private String createdBy;

    @TableField("CREATED_TIME")
    private Date createdTime;

    public String getCreatedBy() {
        return createdBy;
    }

    public void setCreatedBy(String createdBy) {
        this.createdBy = createdBy;
    }

    public Date getCreatedTime() {
        return createdTime;
    }

    public void setCreatedTime(Date createdTime) {
        this.createdTime = createdTime;
    }

    public Long getRelationId() {
        return relationId;
    }

    public void setRelationId(Long relationId) {
        this.relationId = relationId;
    }

    public StandardApi getStandardApi() {
        return standardApi;
    }

    public void setStandardApi(StandardApi standardApi) {
        this.standardApi = standardApi;
    }

    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }

    public Long getProjectVersionId() {
        return projectVersionId;
    }

    public void setProjectVersionId(Long projectVersionId) {
        this.projectVersionId = projectVersionId;
    }

}
